#include <SI_EFM8UB2_Register_Enums.h>                  // SFR declarations
#include "Project_DefsVarsFuncs.h"

unsigned char UpdateDAC_FirstByte;
unsigned char UpdateDAC_SecondByte;

void UpdateDAC(unsigned char ChannelABCorD, unsigned char DACcode)
{
	//ensure that we are not interrupting an ongoing transmission
	while(SPI_State != IDLE);

	/*This switch statement sets the two most significant bits of the 16-bit DAC word
	 * according to which channel is being updated. It also sets the two "operation mode"
	 * bits to binary 01, which corresponds to "write to specified register and update outputs."*/
	switch(ChannelABCorD)
	{
		case DAC_CH_A:
			UpdateDAC_FirstByte = 0x10;
			break;

		case DAC_CH_B:
			UpdateDAC_FirstByte = 0x50;
			break;

		case DAC_CH_C:
			UpdateDAC_FirstByte = 0x90;
			break;

		case DAC_CH_D:
			UpdateDAC_FirstByte = 0xD0;
			break;
	}

	/*The upper four bits of the DAC code are the lower four bits
	 * of the first byte, and the lower four bits of the DAC code are
	 * the upper four bits of the second byte.*/
	UpdateDAC_FirstByte = UpdateDAC_FirstByte | (DACcode >> 4);
	UpdateDAC_SecondByte = DACcode << 4;

	SPI0CN0_SPIEN = 0;	//disable SPI so we can change the clock configuration
	SPI0CFG |= SPI0CFG_CKPOL__BMASK;	//set clock phase for the DAC interface
	SPI0CFG &= ~SPI0CFG_CKPHA__BMASK;	//set clock polarity for the DAC interface
	SPI0CN0_SPIEN = 1;	//re-enable SPI

	DAC_NSS = LOW;	//activate DAC slave select
	SPI0DAT = UpdateDAC_FirstByte;
	SPI_State = FIRST_DAC_BYTE_SENT;
}



