#include <SI_EFM8UB2_Register_Enums.h>                  //SFR declarations
#include "VCPXpress.h"
#include "descriptor.h"
#include "Project_DefsVarsFuncs.h"

uint16_t xdata USBBytesRcvd = 0;                   //holds size of received packet
uint16_t xdata USBBytesTransmitted = 0;			//holds number of bytes actually transmitted
uint8_t xdata USBRxPacket[USB_PACKET_SIZE];     //packet received from host

bit PID_ACTIVE = FALSE;

float Setpoint_Temp;

/**************************************************************************//**
 * VCPXpress callback
 * This function is called by VCPXpress.
 *****************************************************************************/
VCPXpress_API_CALLBACK(myAPICallback)
{
   uint32_t API_InterruptCode;

   //get the code that indicates the reason for the interrupt
   API_InterruptCode = Get_Callback_Source();

   //if the USB connection was just opened
   if (API_InterruptCode & DEVICE_OPEN)
   {
	   //start the first USB read procedure
	   Block_Read(USBRxPacket, USB_PACKET_SIZE, &USBBytesRcvd);
	   /*we will process the received bytes when we get
	   a callback with an RX_COMPLETE interrupt code*/
   }

   if (API_InterruptCode & RX_COMPLETE)   //USB read complete
   {
		   //'C' tells the EFM8 to begin or resume PID control
		   if(USBRxPacket[0] == 'C')
		   {
			   PID_ACTIVE = TRUE;
		   }

		   //'H' tells the EFM8 to halt PID control
		   else if(USBRxPacket[0] == 'H')
		   {
			   PID_ACTIVE = FALSE;

			   /*The heater-drive voltage is held at 0 V
			    * while PID control is halted.*/
			   UpdateDAC(DAC_HEATER, 0);
		   }

		   //'S' indicates that the host is sending the setpoint
		   else if(USBRxPacket[0] == 'S')
		   {
			   /*The setpoint temperature is restricted to
			    * positive integers not greater than 100
			    * degrees C. Scilab sends the setpoint as a
			    * normal binary number, not as ASCII characters,
			    * so that the EFM8 doesn't have to convert
			    * from ASCII to binary.*/
			   Setpoint_Temp = USBRxPacket[1];
		   }

	   //continue with the next USB read procedure
	   Block_Read(USBRxPacket, USB_PACKET_SIZE, &USBBytesRcvd);
   }
}

void TransmitUSB_TempData()
{
		Block_Write(TempData, TEMP_DATA_LEN, &USBBytesTransmitted);
}



